@@ -1,6 +1,6 @@
 class CreateUsers < ActiveRecord::Migration[5.0]
   def self.up
-    create_table "users", :force => true do |t|
+    create_table "users", force: true do |t|
       t.column :name, :string
     end
   end
